@@ -2,13 +2,14 @@ from __future__ import with_statement
 
 '''
 @author: Soizic Laguitton
+
+@organization: I2BM, Neurospin, Gif-sur-Yvette, France
+@organization: CATI, France
 @organization: U{IFR 49<http://www.ifr49.org>}
+
 @license: U{CeCILL version 2<http://www.cecill.info/licences/Licence_CeCILL_V2-en.html>}
 '''
 
-'''
-soma-workflow engine classes
-'''
 
 #-----------------------------------------------------------------------------
 # Imports
@@ -75,7 +76,7 @@ class EngineLoopThread(threading.Thread):
   def stop(self):
     self.engine_loop.stop_loop()
     self.join()
-    print "Soma workflow engine thread ended nicely."
+    #print "Soma workflow engine thread ended nicely."
   
 
 class WorkflowEngineLoop(object):
@@ -88,7 +89,7 @@ class WorkflowEngineLoop(object):
   # each workflow holds a set of EngineJob
   # dict workflow_id -> workflow 
   _workflows = None
-  # Scheduler => Using Drmaa for example
+   
   _scheduler = None
   # database server proxy
   # soma.workflow.database_server
@@ -176,7 +177,8 @@ class WorkflowEngineLoop(object):
         for job in drms_error_jobs.itervalues():
           if job.workflow_id != -1: 
             wf_to_inspect.add(job.workflow_id)
-        
+        drms_error_jobs = {} 
+
         if not (len(self._jobs) == 0 and len(self._workflows) == 0):
           idle_cmpt = 0
         else:
@@ -233,7 +235,7 @@ class WorkflowEngineLoop(object):
               ended_jobs.update(ended_jobs_in_wf)
               wf_to_inspect.add(wf_id)
         
-        # --- 2. Update job status from DRMAA -------------------------------
+        # --- 2. Update job status from the scheduler -------------------------------
         # get back the termination status and terminate the jobs which ended 
         
         wf_jobs = {}
@@ -248,9 +250,14 @@ class WorkflowEngineLoop(object):
           if job.exit_status == None and job.drmaa_id != None:
             try:
               job.status = self._scheduler.get_job_status(job.drmaa_id)
-            except DrmaaError, e:
-              self.logger.error("!!!ERROR!!! get_job_status %s: %s" %(type(e), e))
-              job.status = constants.UNDETERMINED
+            except DRMError, e:
+              self.logger.debug("!!!ERROR!!! get_job_status %s: %s" %(type(e), e))
+              job.status = constants.FAILED
+              job.exit_status = constants.EXIT_ABORTED
+              stderr_file = open(job.stderr_file, "wa")
+              stderr_file.write("Error while requesting the job status %s: %s \nWarning: the job may still be running.\n" %(type(e),e))
+              stderr_file.close()
+              drms_error_jobs[job.job_id] = job
             #self.logger.debug("job " + repr(job.job_id) + " : " + job.status)
             if job.status == constants.DONE or job.status == constants.FAILED:
               #self.logger.debug("End of job %s, drmaaJobId = %s", 
@@ -301,21 +308,23 @@ class WorkflowEngineLoop(object):
         jobs_to_run = self._get_pending_job_to_submit()
 
         # --- 6. Submit jobs -------------------------------------------------
-        drms_error_jobs = {}
         drmaa_id_for_db_up = {}
         for job in jobs_to_run:
           try:
             job.drmaa_id = self._scheduler.job_submission(job)
           except DRMError, e:
-            #TBI how to communicate the error ?
+            #Resubmission ?
             #if job.queue in self._pending_queues:
             #  self._pending_queues[job.queue].insert(0, job)
             #else:
             #  self._pending_queues[job.queue] = [job]
             #job.status = constants.SUBMISSION_PENDING
-            self.logger.error("job %s !!!ERROR!!! %s: %s" %(repr(job.command), type(e), e))
+            self.logger.debug("job %s !!!ERROR!!! %s: %s" %(repr(job.command), type(e), e))
             job.status = constants.FAILED
             job.exit_status = constants.EXIT_ABORTED
+            stderr_file = open(job.stderr_file, "wa")
+            stderr_file.write("Error while submitting the job %s: %s\n" %(type(e),e))
+            stderr_file.close()
             drms_error_jobs[job.job_id] = job
           else:
             drmaa_id_for_db_up[job.job_id] = job.drmaa_id
@@ -670,37 +679,6 @@ class WorkflowEngine(RemoteFileController):
     return self._database_server.get_transfer_information(engine_path, self._user_id)
 
 
-  #def init_transfer_from_cr(self, 
-                            #engine_path,
-                            #client_path, 
-                            #expiration_date, 
-                            #workflow_id, 
-                            #client_paths,
-                            #status):
-    #'''
-    #Initialize the transfer of a file or a directory from the computing resource 
-    #to the client.
-    #'''
-    #if not client_paths:
-      #if os.path.isfile(engine_path):
-        #transfer_type = constants.TR_FILE_CR_TO_C
-      #elif os.path.isdir(engine_path):
-        #transfer_type = constants.TR_DIR_CR_TO_C
-      #else:
-        #pass 
-        ## TBI raise execption
-    #else: #client_paths
-      ## TBI check that the files exit
-      #transfer_type = constants.TR_MFF_CR_TO_C
-
-    #self._database_server.set_transfer_status(engine_path,    
-                                              #constants.TRANSFERING_FROM_CR_TO_CLIENT)
-    #self._database_server.set_transfer_type(engine_path, 
-                                            #transfer_type, 
-                                            #self._user_id)     
-    #return transfer_type
-
-
   def set_transfer_type(self, engine_path, transfer_type):
 
     self._database_server.set_transfer_type(engine_path, 
