@@ -1,10 +1,15 @@
 
 '''
 @author: Soizic Laguitton
+
+@organization: I2BM, Neurospin, Gif-sur-Yvette, France
+@organization: CATI, France
 @organization: U{IFR 49<http://www.ifr49.org>}
+
 @license: U{CeCILL version 2<http://www.cecill.info/licences/Licence_CeCILL_V2-en.html>}
 '''
 
+
 '''
 Engine jobs, workflows and file transfers are defined in a separated 
 module because of the dependencies of the engine module.
@@ -332,7 +337,8 @@ class EngineJob(Job):
           else:
             assert(type(list_el) in types.StringTypes)
             new_list.append(list_el)
-        plain_command.append(str(repr(new_list)))
+        str_list = str(repr(new_list)) 
+        plain_command.append(str_list.replace("'", "\""))
       else:
         assert(type(command_el) in types.StringTypes)
         plain_command.append(command_el)
